Package 'exif'

Title: Read EXIF Metadata from JPEGs
Description: Extracts Exchangeable Image File Format (EXIF) metadata, such as camera make and model, ISO speed and the date-time the picture was taken on, from JPEG images. Incorporates the 'easyexif' <https://github.com/mayanklahiri/easyexif> library.
Authors: Os Keyes [aut, cre], Penelope Hopkins [ctb], Robyn Temple-Wood [ctb], Mayank Lahiri [cph]
Maintainer: Os Keyes <[email protected]>
License: BSD_2_clause + file LICENSE
Version: 0.1.1
Built: 2026-05-12 09:34:07 UTC
Source: https://github.com/ironholds/exif

Help Index


Read EXIF data into R

Description

exif is a package for reading EXIF media metadata into R, returning it as a list in a similar fashion to jsonlite. It depends on the libexif C library, which must be installed for the package to work.

Author(s)

Maintainer: Os Keyes [email protected]

Other contributors:

  • Penelope Hopkins [contributor]

  • Robyn Temple-Wood [contributor]

  • Mayank Lahiri [copyright holder]

See Also

read_exif


Read EXIF Metadata

Description

read_exif reads EXIF metadata from JPEG files, returning it as a data.frame.

Usage

read_exif(files)

Arguments

files

a vector of files to read in.

Value

a data.frame, with each row consisting of the metadata for one file in files. Absent values are represented by an empty string for character columns, and 0 for numeric columns.

Examples

# A simple example using included images
file <- system.file("extdata/dog_test_img.jpg", package="exif")
file_metadata <- read_exif(file)